@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.6   2020/01/01
+ * Version: 1.8.7   2020/05/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -499,6 +499,23 @@ _Bool ccs_correct_word(const char *string)
 	return ccs_correct_word2(string, strlen(string));
 }
 
+/**
+ * ccs_correct_path2 - Check whether the given pathname follows the naming rules.
+ *
+ * @filename: The pathname to check.
+ * @len:      Length of @filename.
+ *
+ * Returns true if @filename follows the naming rules, false otherwise.
+ */
+_Bool ccs_correct_path2(const char *filename, const size_t len)
+{
+	const char *cp1 = memchr(filename, '/', len);
+	const char *cp2 = memchr(filename, '.', len);
+	return cp1 && (!cp2 || (cp1 < cp2)) && ccs_correct_word2(filename, len)
+		&& (len < 24 ||
+		    memcmp(filename, "auto_domain_transition=\"", 24));
+}
+
 /**
  * ccs_correct_path - Check whether the given pathname follows the naming rules.
  *
@@ -508,7 +525,7 @@ _Bool ccs_correct_word(const char *string)
  */
 _Bool ccs_correct_path(const char *filename)
 {
-	return *filename == '/' && ccs_correct_word(filename);
+	return ccs_correct_path2(filename, strlen(filename));
 }
 
 /**
@@ -549,16 +566,15 @@ _Bool ccs_correct_domain(const char *domainname)
 		return true;
 	while (1) {
 		const char *cp = strchr(domainname, ' ');
+		const int len = cp ? cp - domainname : strlen(domainname);
+		if (len == 0)
+			return true;
+		if (!ccs_correct_path2(domainname, len))
+			return false;
 		if (!cp)
-			break;
-		if (*domainname != '/' ||
-		    !ccs_correct_word2(domainname, cp - domainname))
-			goto out;
-		domainname = cp + 1;
+			return true;
+		domainname += len + 1;
 	}
-	return ccs_correct_path(domainname);
-out:
-	return false;
 }
 
 /**
