@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.6   2020/01/01
+ * Version: 1.8.7   2020/05/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -211,9 +211,10 @@ static void tokenize(char *buffer, char *w[5], enum directive_type index)
 			if (!cp)
 				return;
 			while (*cp) {
-				if (*cp++ != ' ' || *cp++ == '/')
+				if (*cp++ != ' ' ||
+				    ccs_correct_path2(cp, strcspn(cp, " ")))
 					continue;
-				cp -= 2;
+				cp--;
 				break;
 			}
 			if (!*cp)
@@ -232,9 +233,10 @@ static void tokenize(char *buffer, char *w[5], enum directive_type index)
 		if (!cp)
 			return;
 		while (*cp) {
-			if (*cp++ != ' ' || *cp++ == '/')
+			if (*cp++ != ' ' ||
+			    ccs_correct_path2(cp, strcspn(cp, " ")))
 				continue;
-			cp -= 2;
+			cp--;
 			break;
 		}
 		if (!*cp)
